define({ "api": [
  {
    "type": "post",
    "url": "/targetCollection",
    "title": "Create Target Collection",
    "name": "CreateTargetCollection",
    "version": "3.0.0",
    "description": "<p>Create a new target collection in your account.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "JSON Object in the request body:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": false,
            "field": "name",
            "description": "<p>The name of the new TargetCollection.</p>"
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target Collection.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "200",
            "description": "<p>The newly created TargetCollection</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "BODY_CONTENT_TOO_LARGE",
            "description": "<p>The content you have sent in the body exceeds the maximum allowed amount of 1MB.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "delete",
    "url": "/targetCollection/:tcId",
    "title": "Delete Target Collection",
    "name": "DeleteTargetCollection",
    "version": "3.0.0",
    "description": "<p>Delete a particular target collection in your account.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be deleted</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "204",
            "description": "<p>Empty Response Body</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/generation/cloudarchive",
    "title": "Generate Cloud Archive",
    "name": "GenerateCloudArchive",
    "version": "3.0.0",
    "description": "<p>Generate a Cloud Archive from an existing Target Collection. The call is asynchronous and contains a path in the response header (Location) from which the status of the generation can be requested (see Status - Generate Cloud Archive).</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be generated</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 2.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "202",
            "description": "<p>Empty Body</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/CloudArchiveEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_IS_UP_TO_DATE",
            "description": "<p>The TargetCollection does not require a Cloud Archive / WTC generation, as no changes have been made since the last generation.</p>"
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_IS_EMPTY",
            "description": "<p>Generation cannot start as the corresponding TargetCollection is empty. Please upload at least one target.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/generation/wtc",
    "title": "Generate WTC",
    "name": "GenerateWTC",
    "version": "3.0.0",
    "description": "<p>Generates a wtc-file out of an existing Target Collection with up to 1000 targets. The call is asynchronous and contains a path in the response header (Location) from which the status of the generation can be requested (see Status - Generate WTC).</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be generated</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p>"
          }
        ],
        "JSON Object in the request body:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": false,
            "field": "sdkVersion",
            "description": "<p>Version of the Wikitude SDK the generated wtc file will be used for. Valid values &quot;3.x&quot;, &quot;4.0&quot;, &quot;4.1&quot;, &quot;5.0&quot;, &quot;5.1&quot;, &quot;5.2&quot;, &quot;5.3&quot;</p>"
          },
          {
            "group": "JSONParam",
            "type": "String",
            "optional": true,
            "field": "eMail",
            "description": "<p>An e-Mail will be sent once wtc file is ready for download.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "202",
            "description": "<p>Empty Body</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/WtmtEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_QUERY_PARAMETER",
            "description": "<p>One or more query parameters are invalid, please check list of allowed values</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_IS_UP_TO_DATE",
            "description": "<p>The TargetCollection does not require a Cloud Archive / WTC generation, as no changes have been made since the last generation.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_IS_EMPTY",
            "description": "<p>Generation cannot start as the corresponding TargetCollection is empty. Please upload at least one target.</p>"
          },
          {
            "group": "Errors",
            "type": "412",
            "optional": false,
            "field": "TARGET_COLLECTION_TOO_LARGE_FOR_WTC",
            "description": "<p>There are more than 1000 targets in the collection.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection",
    "title": "Get all Target Collections",
    "name": "GetAllTargetCollections",
    "version": "3.0.0",
    "description": "<p>Request all target collections in your account.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ],
        "Query Parameters:": [
          {
            "group": "QueryParam",
            "type": "Number",
            "optional": true,
            "field": "skip",
            "description": "<p>Set 0 to start with first target collection, set e.g. to 2 to skip first 2 target collections. Default value: 0</p>"
          },
          {
            "group": "QueryParam",
            "type": "Number",
            "optional": true,
            "field": "limit",
            "description": "<p>Use positive value to define the amount of target collections to return [1, 1000] per page. Default value: 1000</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection[]",
            "optional": false,
            "field": "200",
            "description": "<p>The Array of TargetCollections in your account</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_QUERY_PARAMETER",
            "description": "<p>One or more query parameters are invalid, please check list of allowed values</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection",
    "title": "Get all Target Collections",
    "name": "GetAllTargetCollections",
    "version": "2.0.0",
    "description": "<p>Request all target collections in your account.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 2.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ],
        "Query Parameters:": [
          {
            "group": "QueryParam",
            "type": "Number",
            "optional": true,
            "field": "skip",
            "description": "<p>Set 0 to start with first target collection, set e.g. to 2 to skip first 2 target collections. Default value: 0</p>"
          },
          {
            "group": "QueryParam",
            "type": "Number",
            "optional": true,
            "field": "limit",
            "description": "<p>Use positive value to define the amount of target collections to return [1, 1000] per page. Default value: 1000</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection[]",
            "optional": false,
            "field": "200",
            "description": "<p>The Array of TargetCollections in your account</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_QUERY_PARAMETER",
            "description": "<p>One or more query parameters are invalid, please check list of allowed values</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          },
          {
            "group": "Errors",
            "type": "301",
            "optional": false,
            "field": "TOO_MANY_RESULTS",
            "description": "<p>the number of results is too high</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/generation/cloudarchive/:generationId",
    "title": "Status - Generate Cloud Archive",
    "name": "GetGenerationInformation",
    "version": "3.0.0",
    "description": "<p>Retrieves information status about a particular scheduled cloud archive generation.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "generationId",
            "description": "<p>The id that identifies the cloud archive scheduled generation.</p>"
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be generated.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Generation",
            "optional": false,
            "field": "200",
            "description": "<p>The particular requested generation job details. In case JSON attribute status is 'COMPLETED' the generation finished.</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/CloudArchiveEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "GENERATION_NOT_FOUND",
            "description": "<p>The server has not found anything matching the Request-URI.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId",
    "title": "Get Target Collection",
    "name": "GetTargetCollection",
    "version": "3.0.0",
    "description": "<p>Request a particular target collection in your account.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "200",
            "description": "<p>The particular requested TargetCollection</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/generation/targets/:generationId",
    "title": "Status - Targets Creation",
    "name": "GetTargetsCreationGenerationInformation",
    "version": "3.0.0",
    "description": "<p>Retrieves information status about a particular scheduled targets creation.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "generationId",
            "description": "<p>The id that identifies the target creation.</p>"
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the targets should be added to.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Generation",
            "optional": false,
            "field": "200",
            "description": "<p>The requested job information, including 'status', 'payload' attribute, 'estimatedEnd', 'estimatedLatency' attributes. The 'payload' contains a list of 'creation-items'. Every item has an 'input'-attribute that holds the JSON-Object used for creation (equals item at this index in post-body). Once status is 'COMPLETED' every item also contains a 'target'-attribute (same style as in successful single target creation) or an 'error'-object (same as status 400 error JSON response in single target creation)</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "GENERATION_NOT_FOUND",
            "description": "<p>The server has not found anything matching the Request-URI.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/generation/wtc/:generationId",
    "title": "Status - Generate WTC",
    "name": "GetWTCGenerationInformation",
    "version": "3.0.0",
    "description": "<p>Retrieves information status about a particular scheduled wtc-file generation. Once the status is completed, the wtc information can be retrieved from the target collection (see Get Target Collection).</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "generationId",
            "description": "<p>The id that identifies the scheduled wtc-file generation.</p>"
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be generated.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Generation",
            "optional": false,
            "field": "200",
            "description": "<p>The particular requested generation status.</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/WtmtEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "GENERATION_NOT_FOUND",
            "description": "<p>The server has not found anything matching the Request-URI.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId",
    "title": "Update Target Collection",
    "name": "UpdateTargetCollection",
    "version": "3.0.0",
    "description": "<p>Update a target collection in your account.</p>",
    "group": "TargetCollection",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection that should be updated</p>"
          }
        ],
        "JSON Object in the request body:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": true,
            "field": "name",
            "description": "<p>The new name of the TargetCollection.</p>"
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target Collection.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "TargetCollection",
            "optional": false,
            "field": "200",
            "description": "<p>The updated TargetCollection</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetCollectionEndpoint.js",
    "groupTitle": "TargetCollection",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "BODY_CONTENT_TOO_LARGE",
            "description": "<p>The content you have sent in the body exceeds the maximum allowed amount of 1MB.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/target",
    "title": "Create Target",
    "name": "CreateTarget",
    "version": "3.0.0",
    "description": "<p><span style=\"background-color: #dc0000; color: #ffffff; padding: 2px 4px;\">DEPRECATED!</span> <br /><br />This endpoint will be no longer supported from January 1st 2017 onwards. Have a look at asynchronous approach introduced in 'Create Target<b>s</b>' endpoint. <br />Create a new Target in a Target Collection in your account.</p>",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the Target will be created in.</p>"
          }
        ],
        "JSON Object in the request body:": [
          {
            "group": "JSONParam",
            "type": "String",
            "optional": false,
            "field": "imageUrl",
            "description": "<p>A remote URL pointing to the image that should be used as Target.</p>"
          },
          {
            "group": "JSONParam",
            "type": "String",
            "optional": true,
            "field": "name",
            "description": "<p>The name of the new Target. If not set, a random name will be assigned to the Target. Only following characters are allowed: a-z, A-Z, 0-9, _,-,.</p>"
          },
          {
            "group": "JSONParam",
            "type": "Number",
            "optional": true,
            "field": "physicalHeight",
            "description": "<p>The physical (real world) height of the target, in millimeters.</p>"
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target",
            "optional": false,
            "field": "200",
            "description": "<p>The newly created Target</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_TARGETNAME_CHARACTERS",
            "description": "<p>The target name you have sent contains illegal characters. Only the following characters are allowed: a-z, A-Z, 0-9, _, -, . and the space character. At least one character must be different from the space character.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "DUPLICATE_TARGETNAME_USAGE",
            "description": "<p>The target name you have sent is already taken by another target in your target collection. Please use a different target name.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "IMAGE_NOT_SUPPORTED",
            "description": "<p>You tried to upload an image in a format which is not supported. Supported image formats are PNG and JPEG (.png, .jpg, .jpeg).</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "BODY_CONTENT_TOO_LARGE",
            "description": "<p>The content you have sent in the body exceeds the maximum allowed amount of 1MB.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "DOWNLOAD_FAILED",
            "description": "<p>The system could not download the file you have specified as Target. Please check the URL and access rights.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "403",
            "optional": false,
            "field": "QUOTA_EXCEEDED_TARGETS",
            "description": "<p>You have reached your quota limit and are not allowed to upload targets anymore.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/targets",
    "title": "Create Targets",
    "name": "CreateTargets",
    "version": "3.0.0",
    "description": "<p>Create a set of up to 10 new Targets in a Target Collection in your account.</p>",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the Targets will be created in.</p>"
          }
        ],
        "JSON Array in the request body holding set of Target-Creation information:": [
          {
            "group": "JSONArrayParamTargets",
            "type": "Array",
            "optional": false,
            "field": "List",
            "description": "<p>of JSON Objects as defined in single 'Create Target' endpoint</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Generation",
            "optional": false,
            "field": "202",
            "description": "<p>The task to create the listed targets is scheduled. The response body contains the initial job status. 'location'-header is the url to the GET endpoint that returns current job status information. It is recommended to query this endpoint after 'estimatedLatency' milliseconds, and poll it afterwards every 10 seconds in case job status is still not 'COMPLETED'. Once job status is 'COMPLETED' each item holds a 'target' attribute of the created target or an 'error' attribute.</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_PROPERTY",
            "description": "<p>One or more of the properties you have sent in the body are invalid, or mandatory properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "delete",
    "url": "/targetCollection/:tcId/target/:targetId",
    "title": "Delete Target",
    "name": "DeleteTarget",
    "version": "3.0.0",
    "description": "<p>Delete a particular Target in your account.</p>",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the Target is stored in.</p>"
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "targetId",
            "description": "<p>The id that identifies the Target that should be deleted</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "optional": false,
            "field": "204",
            "description": "<p>Empty Response Body</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target. The target could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/target/:targetId",
    "title": "Get Target",
    "name": "GetTarget",
    "version": "3.0.0",
    "description": "<p>Request a particular Target in a particular Target Collection.</p>",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection.</p>"
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "targetId",
            "description": "<p>The id that identifies the Target.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target",
            "optional": false,
            "field": "200",
            "description": "<p>The particular requested Target</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target. The target could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "get",
    "url": "/targetCollection/:tcId/target",
    "title": "Get Targets",
    "name": "GetTargets",
    "version": "3.0.0",
    "description": "<p>Request targets in a target collection.</p>",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ],
        "Query Parameters:": [
          {
            "group": "QueryParam",
            "type": "String",
            "optional": true,
            "field": "sortby",
            "description": "<p>Targets may be sorted by 'name', 'creDat', 'modDat', 'rating'. Default value: 'creDat'</p>"
          },
          {
            "group": "QueryParam",
            "type": "String",
            "optional": true,
            "field": "sortorder",
            "description": "<p>Targets may be sorted ascending ('asc') or descending ('desc'). Defaut value: 'desc'</p>"
          },
          {
            "group": "QueryParam",
            "type": "Number",
            "optional": true,
            "field": "skip",
            "description": "<p>Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Defaut value: 0</p>"
          },
          {
            "group": "QueryParam",
            "type": "Number",
            "optional": true,
            "field": "limit",
            "description": "<p>Set to 0 for 'all targets' or use positive value to define max. amount of targets to return. Default value: 0</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target[]",
            "optional": false,
            "field": "200",
            "description": "<p>The Array of Targets in the Target Collection</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "INVALID_QUERY_PARAMETER",
            "description": "<p>One or more query parameters are invalid, please check list of allowed values</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  },
  {
    "type": "post",
    "url": "/targetCollection/:tcId/target/:targetId",
    "title": "Update Target",
    "name": "UpdateTarget",
    "version": "3.0.0",
    "description": "<p>Updates properties of a particular Target in your account. Currently following properties are supported: physicalHeight, metadata</p>",
    "group": "Target",
    "parameter": {
      "fields": {
        "Path Parameters in the request path:": [
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "tcId",
            "description": "<p>The id that identifies the TargetCollection the Target is stored in.</p>"
          },
          {
            "group": "PathParam",
            "type": "String",
            "optional": false,
            "field": "targetId",
            "description": "<p>The id that identifies the Target that should be deleted</p>"
          }
        ],
        "JSON Object in the request body:": [
          {
            "group": "JSONParam",
            "type": "Number",
            "optional": true,
            "field": "physicalHeight",
            "description": "<p>The physical (real world) height of the target, in millimeters.</p>"
          },
          {
            "group": "JSONParam",
            "type": "JSON",
            "optional": true,
            "field": "metadata",
            "description": "<p>Arbitrary JSON data that should be stored together with the Target.</p>"
          }
        ],
        "Header Parameters in the request:": [
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "Content-Type",
            "description": "<p>The Content Type of the body. Must be set to application/json.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "Number",
            "optional": false,
            "field": "X-Version",
            "description": "<p>The version of the API to be used. Must be set to 3.</p>"
          },
          {
            "group": "HeaderParam",
            "type": "String",
            "optional": false,
            "field": "X-Token",
            "description": "<p>Your Manager Token.</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "Target",
            "optional": false,
            "field": "200",
            "description": "<p>The updated Target</p>"
          }
        ]
      }
    },
    "filename": "src/endpoint/TargetEndpoint.js",
    "groupTitle": "Target",
    "error": {
      "fields": {
        "Errors": [
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_MISSING",
            "description": "<p>One or more mandatory header properties are missing.</p>"
          },
          {
            "group": "Errors",
            "type": "400",
            "optional": false,
            "field": "HEADER_PROPERTY_INVALID",
            "description": "<p>One or more header properties are invalid.</p>"
          },
          {
            "group": "Errors",
            "type": "401",
            "optional": false,
            "field": "INVALID_TOKEN",
            "description": "<p>The token you have sent is invalid. Please check the X-Token header and place the correct token into the header.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_COLLECTION_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target collection. The TargetCollection could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "404",
            "optional": false,
            "field": "TARGET_NOT_FOUND",
            "description": "<p>The specified ID does not refer to a target. The target could not be found.</p>"
          },
          {
            "group": "Errors",
            "type": "500",
            "optional": false,
            "field": "INTERNAL_SERVER_ERROR",
            "description": "<p>The server cannot complete your request due to an internal error. You can try to send your request again in a couple of minutes. If it still does not work, please contact the Wikitude support.</p>"
          }
        ]
      }
    }
  }
] });
