define({
  "name": "Wikitude Cloud Recognition - RESTful Manager API",
  "version": "3.0.0",
  "description": "The RESTful API specification of the Target Manager Server",
  "title": "Wikitude Cloud Recognition - API Reference",
  "url": "",
  "header": {
    "title": "General Information",
    "content": "<p>This document is the API reference for the Wikitude Cloud Recognition Service. For a more detailed documentation read the <a href=\"http://www.wikitude.com/developer/documentation/cloudrecognition\">Getting Started Guide</a>.</p>\n<h3>API Structure</h3>\n<p>The Manager API follows a simple RESTful API structure. It comprises two main APIs, the <strong>TargetCollection API</strong> and the <strong>Target API</strong>, and follows best practices from RESTful API design.</p>\n<p>Three main HTTP verbs are used in all requests:</p>\n<ul>\n<li><strong>GET</strong> gives access to TargetCollections and Targets stored in the database</li>\n<li><strong>POST</strong> created or manipulates TargetCollections and Targets</li>\n<li><strong>DELETE</strong> deletes TargetCollections or Targets</li>\n</ul>\n<h3>Regional Availability and Base URL</h3>\n<p>Wikitude's Cloud Recognition server are distributed and available world-wide. For the full URL to each endpoint you have to choose a server location and base URL from below.</p>\n<table>\n<thead>\n<tr>\n<th style=\"text-align:left\">Region</th>\n<th style=\"text-align:center\">Base URL for Manager API</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td style=\"text-align:left\">Americas</td>\n<td style=\"text-align:center\"><code>https://api-us.wikitude.com/cloudrecognition</code></td>\n</tr>\n<tr>\n<td style=\"text-align:left\">China</td>\n<td style=\"text-align:center\"><code>https://api-cn.wikitude.com/cloudrecognition</code></td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Europe</td>\n<td style=\"text-align:center\"><code>https://api-eu.wikitude.com/cloudrecognition</code></td>\n</tr>\n</tbody>\n</table>\n<h2>General Response Structure</h2>\n<h3>Response Codes</h3>\n<p>The response code determines if the request was successful. Any successful call will respond with status code 200 (&quot;OK&quot;) or 204 (&quot;No content&quot;). In case of an error, a different response code will be returned, along with an error message (see below). Each API specifies what error codes it may return.</p>\n<h3>Response</h3>\n<p>Each Cloud Recognition API returns one of three different kinds of JSON objects in response to a request:</p>\n<ul>\n<li>A <strong>Target</strong> or an Array of <strong>Targets</strong></li>\n<li>A <strong>TargetCollection</strong> or an Array of <strong>TargetCollections</strong></li>\n<li>An <strong>Error</strong></li>\n</ul>\n<p>Each particular API specifies what it can return. The structure of each object is outlined below:</p>\n<h3>Target</h3>\n<p>A <strong>Target</strong> consists of the following properties:</p>\n<ul>\n<li><strong>id</strong> (String): An ID that uniquely identifies the Target</li>\n<li><strong>name</strong> (String): The Name of the Target, as defined by the user</li>\n<li><strong>imageUrl</strong> (String): The URL pointing to the original, uncompressed and uncropped Target binary file</li>\n<li><strong>thumbnailUrl</strong> (String): The URL pointing to a thumbnail representation of the Target</li>\n<li><strong>rating</strong> (Number): The rating (from 0 to 3) of the Target</li>\n<li><strong>fileSize</strong> (Number): The file size of the original Target binary image file in bytes</li>\n<li><strong>physicalHeight</strong> (Number): The physical (real world) height of the target. For more information check class CloudTracker of the <a href=\"http://www.wikitude.com/developer/documentation/android\">Wikitude SDK</a></li>\n<li><strong>creDat</strong> (Number): A timestamp when the Target was created (as returned by JavaScript's <code>Date.now()</code> function)</li>\n<li><strong>modDat</strong> (Number): A timestamp when the Target was last modified (as returned by JavaScript's <code>Date.now()</code> function)</li>\n<li><strong>metadata</strong> (JSON): Arbitrary JSON data that is stored together with the target.</li>\n</ul>\n<h3>TargetCollection</h3>\n<p>A <strong>TargetCollection</strong> consists of the following properties:</p>\n<ul>\n<li><strong>id</strong> (String): An ID that uniquely identifies the TargetCollection</li>\n<li><strong>name</strong> (String): The Name of the TargetCollection, as defined by the user</li>\n<li><strong>creDat</strong> (Number): A timestamp when the TargetCollection was created (as returned by JavaScript's <code>Date.now()</code> function)</li>\n<li><strong>modDat</strong> (Number): A timestamp when the TargetCollection was last modified (as returned by JavaScript's <code>Date.now()</code> function)</li>\n<li><strong>metadata</strong> (JSON): Arbitrary JSON data that is stored together with the TargetCollection.</li>\n<li><strong>wtc</strong> (Array): An array of wtcFiles that were generated out of the TargetCollection already. Every element contains &quot;version&quot;, &quot;url&quot;, &quot;nrOfTargets&quot; and &quot;creDat&quot;. Only latest wtcFiles are stored, list is cleared on target modifications. Check &quot;Generate WTC File&quot; Endpoint for more details</li>\n</ul>\n<h3>Error</h3>\n<p>In case the server cannot serve the request successfully, it will respond with an error object. The Error object consists of the following properties:</p>\n<ul>\n<li><strong>code</strong> (Number): An internal error code that further specifies the error (currently, we copy the response code from the HTTP response in here, but we might want to change this in the future)</li>\n<li><strong>reason</strong> (String): A short title that tells the developer what has gone wrong</li>\n<li><strong>message</strong> (String): A more detailed explanation of what has gone wrong, and what needs to be done to prevent the error.</li>\n<li><strong>cause</strong> (JSON): The exact cause of the error</li>\n<li><strong>moreInfo</strong> (String): Optional more information how to resolve the error</li>\n</ul>\n<h4>Example</h4>\n<pre><code>{\n&quot;code&quot;: 400,\n&quot;reason&quot;: &quot;HEADER_PROPERTY_MISSING&quot;,\n&quot;message&quot;: &quot;One or more mandatory header properties are missing.&quot;,\n&quot;cause&quot;: [\n    {\n        &quot;item&quot;: &quot;X-Token&quot;,\n        &quot;value&quot;: &quot;&quot;\n    }\n],\n&quot;moreInfo&quot;: &quot;http://www.wikitude.com/developer/documentation/cloud&quot;\n}</code></pre>\n"
  },
  "sampleUrl": false,
  "apidoc": "0.2.0",
  "generator": {
    "name": "apidoc",
    "time": "2017-02-16T08:46:21.261Z",
    "url": "http://apidocjs.com",
    "version": "0.16.1"
  }
});
